@@ -2,7 +2,7 @@
  * Convert a processed survey data file to another format.
  */
 
-/* Copyright (C) 1994-2004,2008,2010,2011,2013,2014,2018 Olly Betts
+/* Copyright (C) 1994-2004,2008,2010,2011,2013,2014,2018,2020 Olly Betts
  * Copyright (C) 2004 John Pybus (SVG Output code)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,6 +39,7 @@
 #include "str.h"
 #include "useful.h"
 
+#include <iostream>
 #include <string>
 
 using namespace std;
@@ -124,10 +125,15 @@ main(int argc, char **argv)
    static struct help_msg help[] = {
 	/*			<-- */
 	{HLP_ENCODELONG(0),   /*only load the sub-survey with this prefix*/199, 0},
+	/* TRANSLATORS: These example input values should not be translated. */
 	{HLP_ENCODELONG(1),   /*scale (50, 0.02, 1:50 and 2:100 all mean 1:50)*/217, 0},
+	/* TRANSLATORS: These example input values should not be translated. */
 	{HLP_ENCODELONG(2),   /*bearing (90, 90d, 100g all mean 90°)*/460, 0},
+	/* TRANSLATORS: These example input values should not be translated. */
 	{HLP_ENCODELONG(3),   /*tilt (45, 45d, 50g, 100% all mean 45°)*/461, 0},
+	/* TRANSLATORS: Don't translate example command line option --tilt=-90 */
 	{HLP_ENCODELONG(4),   /*plan view (equivalent to --tilt=-90)*/462, 0},
+	/* TRANSLATORS: Don't translate example command line option --tilt=0 */
 	{HLP_ENCODELONG(5),   /*elevation view (equivalent to --tilt=0)*/463, 0},
 	{HLP_ENCODELONG(6),   /*underground survey legs*/476, 0},
 	{HLP_ENCODELONG(7),   /*surface survey legs*/464, 0},
@@ -276,7 +282,7 @@ main(int argc, char **argv)
 	 if (units == 'g') {
 	     pan *= 0.9;
 	 }
-	 bit = EXPORT_3D;
+	 bit = ORIENTABLE;
 	 break;
        }
        case OPT_TILT: {
@@ -302,16 +308,16 @@ main(int argc, char **argv)
 	 } else if (units == '%') {
 	     tilt = deg(atan(tilt * 0.01));
 	 }
-	 bit = EXPORT_3D;
+	 bit = ORIENTABLE;
 	 break;
        }
        case OPT_PLAN:
 	 tilt = -90.0;
-	 bit = EXPORT_3D;
+	 bit = ORIENTABLE;
 	 break;
        case OPT_ELEV:
 	 tilt = 0.0;
-	 bit = EXPORT_3D;
+	 bit = ORIENTABLE;
 	 break;
        case 't': /* Text height */
 	 text_height = cmdline_double_arg();
@@ -426,7 +432,7 @@ main(int argc, char **argv)
        show_mask |= export_format_info[format].defaults;
    }
 
-   if (!(format_info_mask & EXPORT_3D)) {
+   if (!(format_info_mask & ORIENTABLE)) {
        pan = 0.0;
        tilt = -90.0;
    }
@@ -446,8 +452,12 @@ main(int argc, char **argv)
 	  fatalerror(/*Couldn’t write file “%s”*/402, fnm_out);
        }
    } catch (const wxString & m) {
-       wxFprintf(stderr, wxT("%s: %s: %s\n"),
-		 msg_appname(), wmsg(/*error*/93), m);
+       wxString r = msg_appname();
+       r += ": ";
+       r += wmsg(/*error*/93);
+       r += ": ";
+       r += m;
+       wcerr << r.c_str() << '\n';
    }
 
    return 0;
